==> share_apps-0.2.8.tar.gz: lib/screens/email_invitation_loading_screen.dart <==
import 'dart:convert';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:http/http.dart' as http;
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/screens/home_screen.dart';
import 'package:share_apps/screens/invite_email_screen.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';

UserBean userBean;

class EmailInvitationLoading extends StatefulWidget {
  @override
  _EmailInvitationLoadingState createState() => _EmailInvitationLoadingState();
}

class _EmailInvitationLoadingState extends State<EmailInvitationLoading> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    sendEmailInvite();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      color: Colors.white,
      home: Scaffold(
        body: Container(
          color: Colors.white,
          child: Column(
            children: [
              Expanded(
                flex: 1,
                child: Align(
                  alignment: Alignment.bottomCenter,
                  child: InkWell(
                    onTap: () async {},
                    child: Image.asset(
                      'images/ic_logo.png',
                      width: 50,
                      height: 50,
                    ),
                  ),
                ),
              ),
              AddSizeBox(100, 0),
              Expanded(
                flex: 1,
                child: Container(
                  child: Text(
                    StringUtils.EMAIL_INVITAION_WAIT_MESSAGE,
                    textAlign: TextAlign.center,
                    style: TextStyle(
                        decoration: TextDecoration.none,
                        fontSize: 15,
                        color: Colors.black),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  Future<void> sendEmailInvite() async {
    var body = json.encode({
      StringUtils.EMAIL_PARAM : StringUtils.APP_EMAIL,
    });
    var map =
        await CommonUtils.apiCall(Uri.parse(StringUtils.API_INVITE_EMAIL), body, context);
    setState(() {
      isLoading = false;
    });
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      Navigator.pushReplacement(
          context,
          MaterialPageRoute(
              builder: (context) => InviteEmail(map['url'].toString())));
    } else {
      Navigator.pop(context);
    }
  }
}

==> share_apps-0.2.13.tar.gz: lib/screens/email_invitation_loading_screen.dart <==
import 'dart:convert';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:http/http.dart' as http;
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/screens/home_screen.dart';
import 'package:share_apps/screens/invite_email_screen.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';

// UserBean userBean;

class EmailInvitationLoading extends StatefulWidget {
  @override
  _EmailInvitationLoadingState createState() => _EmailInvitationLoadingState();
}

class _EmailInvitationLoadingState extends State<EmailInvitationLoading> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    sendEmailInvite();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      color: Colors.white,
      home: Scaffold(
        body: Container(
          color: Colors.white,
          child: Column(
            children: [
              Expanded(
                flex: 1,
                child: Align(
                  alignment: Alignment.bottomCenter,
                  child: InkWell(
                    onTap: () async {},
                    child: Image.network(
                      'https://royalty.shareapps.net/img/green-icon.png',
                      width: 50,
                      height: 50,
                    ),
                  ),
                ),
              ),
              AddSizeBox(100, 0),
              Expanded(
                flex: 1,
                child: Container(
                  child: Text(
                    StringUtils.EMAIL_INVITAION_WAIT_MESSAGE,
                    textAlign: TextAlign.center,
                    style: TextStyle(
                        decoration: TextDecoration.none,
                        fontSize: 15,
                        color: Colors.black),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  Future<void> sendEmailInvite() async {
    var body = json.encode({
      StringUtils.EMAIL_PARAM: StringUtils.APP_EMAIL,
    });
    var map = await CommonUtils.apiCall(
        Uri.parse(StringUtils.API_INVITE_EMAIL), body, context);
    setState(() {
      isLoading = false;
    });
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      Navigator.pushReplacement(
          context,
          MaterialPageRoute(
              builder: (context) => InviteEmail(map['url'].toString())));
    } else {
      Navigator.pop(context);
    }
  }
}
